# Project

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**description** | **str** |  | 
**cloud_id** | **str** |  | [optional] 
**initial_cluster_config** | **str** |  | [optional] 
**id** | **str** |  | 
**created_at** | **datetime** |  | 
**creator_id** | **str** |  | 
**is_owner** | **bool** |  | 
**directory_name** | **str** |  | 
**cloud** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


